Welcome to BAGO’s documentation! — BAGO 0.0.1 documentation

# Welcome to BAGO’s documentation!

BAGO is a Python package for Bayesian Optimization of Liquid Chromatographic Elution Gradient. Use BAGO to design a gradient for your LC-MS/MS analysis today!

BAGO enables:

Highly efficient gradient optimization

  Find an optimal gradient for your LC-MS/MS analysis within 10 runs. Wonder why BAGO is efficient? Read more about Acquisition functions.

Omics-scale evaluation on compound separation

  Separation efficiency was defined to evaluate the performance of a gradient. Wonder how omics-scale evaluation is achieved? Read more about Encodings.

Broader discovery of chemical space

  Expand your discovery of chemical space by improving identification and quantification. Wonder how BAGO can help you? Read more about Applications.

## Get Started

Start your journey with BAGO by reading the following pages:

- Background: Backgrounds

- Getting Started: With A Jupyter Notebook | With A GUI Software |

## BAGO Functions

Learn more about the functions in BAGO.

- Functions to manipulate MS data: MS data (object) | Read MS data | Generate second gradient | Find top signals | Compute Separation Efficiency | Get BPC | Plot BPC | Spectral similarity | Get unique MS2 spectra | Get unique m/z | Get mobile phase percentage | Output gradient

- Functions to build Bayesian optimization model: Gaussian process regression (object) | Gaussian process regression fitting | Generate search space | Compute next gradient | Update model | Acquisition functions

## Useful Links

- BAGO on GitHub:

    BAGO source code and more details

- BAGO on PyPI:

    BAGO Python package

## Citation

Please cite:

- BAGO paper:

## Further Reading

- Bayesian optimization:

  > - A Tutorial on Bayesian Optimization

  > - A Tutorial on Bayesian Optimization of Expensive Cost Functions, with Application to Active User Modeling and Hierarchical Reinforcement Learning

- Gaussian process regression:

  > - Gaussian process in scikit-learn

  > - Gaussian Processes for Machine Learning

- Liquid chromtography:

  > - Introduction to Modern Liquid Chromatography